# eCon
SDK for Niantong devices.

[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye-up.com)

For more information, see the online [documentation](https://niantong-intelligence.github.io/eConEXG/).

# Installation

## Prerequisites

On all non-Windows platforms and for some Windows-Python combinations, you must first obtain a liblsl shared library to use lsl feature. See the [liblsl repo documentation](https://github.com/sccn/liblsl) for further details.

## Get eConEXG from PyPI

* `pip install eConEXG`